summaryrefslogtreecommitdiffstats
path: root/chrome_frame/chrome_launcher_utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome_frame/chrome_launcher_utils.h')
-rw-r--r--chrome_frame/chrome_launcher_utils.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/chrome_frame/chrome_launcher_utils.h b/chrome_frame/chrome_launcher_utils.h
index 4f5cdad..699e75e 100644
--- a/chrome_frame/chrome_launcher_utils.h
+++ b/chrome_frame/chrome_launcher_utils.h
@@ -9,6 +9,7 @@
class CommandLine;
class FilePath;
+template <class C> class scoped_ptr;
namespace chrome_launcher {
@@ -19,15 +20,19 @@ extern const wchar_t kLauncherExeBaseName[];
// flags needed before launching.
//
// The command-line may use the Chrome executable directly, or use an in-between
-// process if needed for security/elevation purposes. You must delete the
-// returned command line.
-CommandLine* CreateLaunchCommandLine();
+// process if needed for security/elevation purposes.
+//
+// On success, returns true and populates command_line, which must be non-NULL,
+// with the launch command line.
+bool CreateLaunchCommandLine(scoped_ptr<CommandLine>* command_line);
// Creates a command line suitable for launching the specified command through
// Google Update.
//
-// You must delete the returned command line.
-CommandLine* CreateUpdateCommandLine(const std::wstring& update_command);
+// On success, returns true and populates command_line, which must be non-NULL,
+// with the update command line.
+bool CreateUpdateCommandLine(const std::wstring& update_command,
+ scoped_ptr<CommandLine>* command_line);
// Returns the full path to the Chrome executable.
FilePath GetChromeExecutablePath();